gwss
==========

.. toctree::
   :maxdepth: 3
   :caption: Contents:


   installation
   guide
   modules
   acknowledgements

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`